@@ -13,20 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
 
 import base64
 import binascii
 from decimal import ROUND_HALF_UP, Decimal, localcontext
 from distutils.util import strtobool
-from typing import TYPE_CHECKING, Any, Dict, Optional
+from typing import TYPE_CHECKING, Any
 
 from aiohomekit.exceptions import CharacteristicPermissionError, FormatError
 from aiohomekit.protocol.statuscodes import HapStatusCode
 from aiohomekit.protocol.tlv import TLV, TlvParseException
 from aiohomekit.tlv8 import tlv_array
+from aiohomekit.uuid import normalize_uuid
 
 from .characteristic_formats import CharacteristicFormats
-from .characteristic_types import CharacteristicsTypes
 from .data import characteristics
 from .permissions import CharacteristicPermissions
 
@@ -59,13 +60,10 @@ NUMBER_TYPES = INTEGER_TYPES + [CharacteristicFormats.float]
 
 
 class Characteristic:
-    def __init__(self, service: "Service", characteristic_type: str, **kwargs) -> None:
+    def __init__(self, service: Service, characteristic_type: str, **kwargs) -> None:
         self.service = service
         self.iid = service.accessory.get_next_id()
-        try:
-            self.type = CharacteristicsTypes.get_uuid(characteristic_type)
-        except KeyError:
-            self.type = characteristic_type
+        self.type = normalize_uuid(characteristic_type)
 
         self.perms = self._get_configuration(
             kwargs, "perms", [CharacteristicPermissions.paired_read]
@@ -111,10 +109,10 @@ class Characteristic:
 
     def _get_configuration(
         self,
-        kwargs: Dict[str, Any],
+        kwargs: dict[str, Any],
         key: str,
-        default: Optional[Any] = None,
-    ) -> Optional[Any]:
+        default: Any | None = None,
+    ) -> Any | None:
         if key in kwargs:
             return kwargs[key]
         if self.type not in characteristics:
@@ -123,13 +121,6 @@ class Characteristic:
             return default
         return characteristics[self.type][key]
 
-    @property
-    def type_name(self):
-        try:
-            return CharacteristicsTypes.get_short(self.type)
-        except KeyError:
-            return None
-
     @property
     def status(self) -> HapStatusCode:
         return self._status
